@@ -4,7 +4,7 @@ import json
 import os
 import sys
 import sysconfig
-from subprocess import check_output, CalledProcessError
+from subprocess import check_output, PIPE, CalledProcessError
 from unittest.mock import patch
 
 import pytest
@@ -17,11 +17,20 @@ from jupyter_core.paths import (
 )
 
 
+resetenv = patch.dict(os.environ)
+
+def setup_module():
+    resetenv.start()
+    os.environ.pop('JUPYTER_PREFER_ENV_PATH', None)
+
+def teardown_module():
+    resetenv.stop()
+
 def get_jupyter_output(cmd):
     """Get output of a jupyter command"""
     if not isinstance(cmd, list):
         cmd = [cmd]
-    return check_output([sys.executable, '-m', 'jupyter_core'] + cmd).decode('utf8').strip()
+    return check_output([sys.executable, '-m', 'jupyter_core'] + cmd, stderr=PIPE).decode('utf8').strip()
 
 
 def write_executable(path, source):
@@ -109,8 +118,10 @@ def test_help():
 
 
 def test_subcommand_not_found():
-    with pytest.raises(CalledProcessError):
+    with pytest.raises(CalledProcessError) as excinfo:
         get_jupyter_output('nonexistant-subcommand')
+    stderr = excinfo.value.stderr.decode('utf8')
+    assert 'Jupyter command `jupyter-nonexistant-subcommand` not found.' in stderr
 
 @patch.object(sys, 'argv', [__file__] + sys.argv[1:])
 def test_subcommand_list(tmpdir):
